pub enum ParagraphJustification {
Unknown = 0,
Left = 1,
Center = 2,
Right = 3,
}Expand description
Paragraph alignment.
Variants
Unknown = 0
The alignment is unclear.
Left = 1
Each line, except possibly the first, is flush to the same left tab stop.
Center = 2
The text lines of the paragraph are centered about a line going down through their middle of the text lines.
Right = 3
Each line, except possibly the first, is flush to the same right tab stop.