Monitor

Struct Monitor 

pub struct Monitor<C> { /* private fields */ }
Monitor tracks text recognition progress and can be used to set the timeout.

Implementations

Source

impl Monitor<()>

pub fn new() -> Self

Creates new monitor without timeout and without cancel callback.

Source

impl<C: FnMut(i32) -> bool> Monitor<C>

pub fn with_cancel_callback(cancel: C) -> Self

Creates new monitor with cancel callback.

pub fn get_cancel_callback(&mut self) -> &mut C

Returns cancel callback.

Source

impl<C> Monitor<C>

pub fn set_progress_callback_raw(&mut self, callback: TessProgressFunc)

Set progress callback function.

pub fn get_progress(&self) -> u32

Get progress in [0; 100] range.

pub fn set_timeout(&mut self, timeout: Duration)

Set text recognition timeout.