ParagraphInfo

Struct ParagraphInfo 

pub struct ParagraphInfo {
    pub justification: ParagraphJustification,
    pub is_list_item: bool,
    pub is_crown: bool,
    pub first_line_indent: i32,
}
Paragraph information.

Fields

justification: ParagraphJustification

Paragraph alignment.

is_list_item: bool

Whether we believe this is a member of an ordered or unordered list or not.

is_crown: bool

Whether the first line of the paragraph is aligned with the other lines of the paragraph even though subsequent paragraphs have first line indents. This typically indicates that this is the continuation of a previous paragraph or that it is the very first paragraph in the chapter.

first_line_indent: i32

First line indentation with respect to justification.

Can be negative.