pub enum PageSegmentationMode {
Show 14 variants
OsdOnly = 0,
AutoOsd = 1,
AutoOnly = 2,
Auto = 3,
SingleColumn = 4,
SingleBlockVertText = 5,
SingleBlock = 6,
SingleLine = 7,
SingleWord = 8,
CircleWord = 9,
SingleChar = 10,
SparseText = 11,
SparseTextOsd = 12,
RawLine = 13,
}Expand description
Page layout analysis modes.
Variants
OsdOnly = 0
Orientation and script detection only.
AutoOsd = 1
Automatic page segmentation with orientation and script detection (OSD).
AutoOnly = 2
Automatic page segmentation, but no OSD, or OCR.
Auto = 3
Fully automatic page segmentation, but no OSD.
SingleColumn = 4
Assume a single column of text of variable sizes.
SingleBlockVertText = 5
Assume a single uniform block of vertically aligned text.
SingleBlock = 6
Assume a single uniform block of text (default).
SingleLine = 7
Treat the image as a single text line.
SingleWord = 8
Treat the image as a single word.
CircleWord = 9
Treat the image as a single word in a circle.
SingleChar = 10
Treat the image as a single character.
SparseText = 11
Find as much text as possible in no particular order.
SparseTextOsd = 12
Sparse text with orientation and script det.
RawLine = 13
Treat the image as a single text line, bypassing hacks that are Tesseract-specific.